unit MainForm;

// https://docs.microsoft.com/en-us/windows/uwp/networking/httpclient
// https://www.youtube.com/watch?time_continue=5&v=nOFNc2uTmGs&feature=emb_logo
// https://www.youtube.com/watch?v=6IgDgydrCFo

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.StdCtrls, Vcl.WinXCtrls,
  System.ImageList, Vcl.ImgList, Vcl.ExtCtrls;

type
  TFormMain = class(TForm)
    btnSearch: TButton;
    Memo1: TMemo;
    edtURL: TEdit;
    ImageList1: TImageList;
    PanelToolbar: TPanel;
    procedure btnSearchClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  FormMain: TFormMain;

implementation

{$R *.dfm}

uses
  System.Win.WinRT,
  Winapi.WinRT,
  Winapi.CommonTypes,
  Winapi.Foundation,
  Winapi.WebRT;

type
  // La callback (come tutti gli oggetti WinRT deve ereditare da TInspectableObject)
  THttpStringRequestCompletedCallback = class(TInspectableObject,
    AsyncOperationWithProgressCompletedHandler_2__HSTRING__Http_HttpProgress_Delegate_Base,
    AsyncOperationWithProgressCompletedHandler_2__HSTRING__Http_HttpProgress)
  public
    procedure Invoke(asyncInfo: IAsyncOperationWithProgress_2__HSTRING__Http_HttpProgress;
      asyncStatus: AsyncStatus); safecall;
  end;

{ Some utilities }

function CreateWinRTStr(const Value: string): HSTRING;
begin
  WindowsCreateString(PChar(Value), Length(Value), Result);
end;

procedure Log(const AMessage: string);
begin
  FormMain.Memo1.Lines.Add(AMessage);
end;

{ TFormMain }

procedure TFormMain.btnSearchClick(Sender: TObject);
var
  Uri: IUriRuntimeClass;
  HttpClient: Http_IHttpClient;
  Progress: IAsyncOperationWithProgress_2__HSTRING__Http_HttpProgress;
begin
  Memo1.Clear;
  Uri := Winapi.Foundation.TUri.CreateUri(CreateWinRTStr(edtURL.Text));
  HttpClient := THttp_HttpClient.Create();

  Progress := HttpClient.GetStringAsync(Uri);
  Progress.Completed := THttpStringRequestCompletedCallback.Create;
end;

procedure TFormMain.FormCreate(Sender: TObject);
begin
  Memo1.Clear;
end;

{ THttpStringRequestCompletedCallback }

procedure THttpStringRequestCompletedCallback.Invoke(
  asyncInfo: IAsyncOperationWithProgress_2__HSTRING__Http_HttpProgress;
  asyncStatus: AsyncStatus);
begin
  Log('COMPLETED');
  if asyncStatus = Winapi.CommonTypes.AsyncStatus.Error then
  begin
    Log('ERROR');
    Exit;
  end;

  Log( asyncInfo.GetResults.ToString );
end;

end.
