unit CNGCrypt.WinAPI;

interface

uses
  WinApi.Windows;

const
  BCRYPT_AES_ALGORITHM = 'AES';

  // https://docs.microsoft.com/en-us/windows/win32/seccng/cng-property-identifiers
  BCRYPT_OBJECT_LENGTH = 'ObjectLength';
  BCRYPT_BLOCK_LENGTH = 'BlockLength';

  BCRYPT_CHAINING_MODE = 'ChainingMode';
  BCRYPT_CHAIN_MODE_CBC = 'ChainingModeCBC';
  BCRYPT_CHAIN_MODE_CCM = 'ChainingModeCCM';
  BCRYPT_CHAIN_MODE_CFB = 'ChainingModeCFB';
  BCRYPT_CHAIN_MODE_ECB = 'ChainingModeECB';
  BCRYPT_CHAIN_MODE_GCM = 'ChainingModeGCM';
  BCRYPT_CHAIN_MODE_NA = 'ChainingModeN/A';

  // See https://docs.microsoft.com/en-us/windows/win32/api/bcrypt/nf-bcrypt-bcryptexportkey
  BCRYPT_OPAQUE_KEY_BLOB = 'OpaqueKeyBlob';

  // See https://docs.microsoft.com/en-us/windows/win32/api/bcrypt/nf-bcrypt-bcryptencrypt
  BCRYPT_BLOCK_PADDING = 1;


//NTSTATUS BCryptOpenAlgorithmProvider(
//  BCRYPT_ALG_HANDLE *phAlgorithm,
//  LPCWSTR           pszAlgId,
//  LPCWSTR           pszImplementation,
//  ULONG             dwFlags
//);

function BCryptOpenAlgorithmProvider(
  var phAlgorithm: Pointer;
  pszAlgId: PWideChar;
  pszImplementation: PWideChar;
  dwFlags: ULONG
): Integer; stdcall; external 'Bcrypt.dll';

//NTSTATUS BCryptCloseAlgorithmProvider(
//  BCRYPT_ALG_HANDLE hAlgorithm,
//  ULONG             dwFlags
//);

function BCryptCloseAlgorithmProvider(
  hAlgorithm: Pointer;
  dwFlags: ULONG
): Integer; stdcall; external 'Bcrypt.dll';

//NTSTATUS BCryptGetProperty(
//  BCRYPT_HANDLE hObject,
//  LPCWSTR       pszProperty,
//  PUCHAR        pbOutput,
//  ULONG         cbOutput,
//  ULONG         *pcbResult,
//  ULONG         dwFlags
//);

function BCryptGetProperty(
  hObject: Pointer;
  pszProperty: PWideChar;
  var pbOutput: DWORD;
  cbOutput: ULONG;
  var pcbResult: ULONG;
  dwFlagd: ULONG
): Integer; stdcall; external 'Bcrypt.dll';

//NTSTATUS BCryptSetProperty(
//  BCRYPT_HANDLE hObject,
//  LPCWSTR       pszProperty,
//  PUCHAR        pbInput,
//  ULONG         cbInput,
//  ULONG         dwFlags
//);

function BCryptSetProperty(
  hObject: Pointer;
  pszProperty: PWideChar;
  pbInput: PWideChar;
  cbInput: ULONG;
  dwFlags: ULONG
): Integer; stdcall; external 'Bcrypt.dll';

//NTSTATUS BCryptGenerateSymmetricKey(
//  BCRYPT_ALG_HANDLE hAlgorithm,
//  BCRYPT_KEY_HANDLE *phKey,
//  PUCHAR            pbKeyObject,
//  ULONG             cbKeyObject,
//  PUCHAR            pbSecret,
//  ULONG             cbSecret,
//  ULONG             dwFlags
//);

function BCryptGenerateSymmetricKey(
  hAlgorithm: Pointer;
  var phKey: Pointer;
  pbKeyObject: Pointer;
  cbKeyObject: ULONG;
  pbSecret: Pointer;
  cbSecret: ULONG;
  dwFlags: ULONG
): Integer; stdcall; external 'Bcrypt.dll';

//NTSTATUS BCryptDestroyKey(
//  BCRYPT_KEY_HANDLE hKey
//);

function BCryptDestroyKey(
  hKey: Pointer
): Integer; stdcall; external 'Bcrypt.dll';

//NTSTATUS BCryptEncrypt(
//  BCRYPT_KEY_HANDLE hKey,
//  PUCHAR            pbInput,
//  ULONG             cbInput,
//  VOID              *pPaddingInfo,
//  PUCHAR            pbIV,
//  ULONG             cbIV,
//  PUCHAR            pbOutput,
//  ULONG             cbOutput,
//  ULONG             *pcbResult,
//  ULONG             dwFlags
//);

function BCryptEncrypt(
  hKey: Pointer;
  pbInput: Pointer;
  cbInput: ULONG;
  pPaddingInfo: Pointer;
  pbIV: Pointer;
  cbIV: ULONG;
  pbOutput: Pointer;
  cbOutput: ULONG;
  var pcbResult: ULONG;
  dwFlags: ULONG
): Integer; stdcall; external 'Bcrypt.dll';

//NTSTATUS BCryptDecrypt(
//  BCRYPT_KEY_HANDLE hKey,
//  PUCHAR            pbInput,
//  ULONG             cbInput,
//  VOID              *pPaddingInfo,
//  PUCHAR            pbIV,
//  ULONG             cbIV,
//  PUCHAR            pbOutput,
//  ULONG             cbOutput,
//  ULONG             *pcbResult,
//  ULONG             dwFlags
//);

function BCryptDecrypt(
  hKey: Pointer;
  pbInput: Pointer;
  cbInput: ULONG;
  pPaddingInfo: Pointer;
  pbIV: Pointer;
  cbIV: ULONG;
  pbOutput: Pointer;
  cbOutput: ULONG;
  var pcbResult: ULONG;
  dwFlags: ULONG
): Integer; stdcall; external 'Bcrypt.dll';

implementation

end.
